Module async_support

Module async_support 

Generic async support with which you can use you own thread pool by implementing the BlockingExecutor trait.

Structs

AsyncArchiveIterator
Asynchronous streaming iterator over the contents of an archive.

Traits

BlockingExecutor

Functions

list_archive_entries
Async version of list_archive_entries.
list_archive_entries_with_encoding
Async version of list_archive_entries_with_encoding(crate:: list_archive_entries_with_encoding).
list_archive_files
Async version of list_archive_files.
list_archive_files_with_encoding
Async version of list_archive_files_with_encoding(crate:: list_archive_files_with_encoding).
uncompress_archive
Async version of uncompress_archive.
uncompress_archive_file
Async version of uncompress_archive_file.
uncompress_archive_file_with_encoding
Async version of uncompress_archive_file_with_encoding(crate:: uncompress_archive_file_with_encoding).
uncompress_archive_with_encoding
Async version of uncompress_archive_with_encoding(crate:: uncompress_archive_with_encoding).
uncompress_data
Async version of uncompress_data.

Type Aliases

AsyncEntryFilterCallbackFn
A filter callback for the async archive iterator.