ArchiveIteratorBuilder

Struct ArchiveIteratorBuilder 

pub struct ArchiveIteratorBuilder<R> { /* private fields */ }
Builder for a futures-backed AsyncArchiveIterator.

Mirrors crate::ArchiveIteratorBuilder but produces an asynchronous futures_core::Stream of entries over a futures_io::AsyncRead + AsyncSeek source. The source must be Send + 'static because it is moved into a blocking worker that hosts the sync libarchive state for the iterator’s lifetime.

Implementations

Source

impl<R> ArchiveIteratorBuilder<R>
where R: AsyncRead + AsyncSeek + Unpin + Send + 'static,

pub fn new(source: R) -> ArchiveIteratorBuilder<R>

pub fn decoder(self, decoder: DecodeCallback) -> ArchiveIteratorBuilder<R>

pub fn filter<F>(self, filter: F) -> ArchiveIteratorBuilder<R>
where F: Fn(&str, &stat) -> bool + Send + Sync + 'static,

pub fn with_password( self, password: ArchivePassword, ) -> ArchiveIteratorBuilder<R>

pub fn build(self) -> AsyncArchiveIterator