Generic async support with which you can use you own thread pool by
implementing the BlockingExecutor trait.
Structs
- Async
Archive Iterator - Asynchronous streaming iterator over the contents of an archive.
Traits
Functions
- list_
archive_ entries - Async version of
list_archive_entries. - list_
archive_ entries_ with_ encoding - Async version of
list_archive_entries_with_encoding(crate:: list_archive_entries_with_encoding). - list_
archive_ files - Async version of
list_archive_files. - list_
archive_ files_ with_ encoding - Async version of
list_archive_files_with_encoding(crate:: list_archive_files_with_encoding). - uncompress_
archive - Async version of
uncompress_archive. - uncompress_
archive_ file - Async version of
uncompress_archive_file. - uncompress_
archive_ file_ with_ encoding - Async version of
uncompress_archive_file_with_encoding(crate:: uncompress_archive_file_with_encoding). - uncompress_
archive_ with_ encoding - Async version of
uncompress_archive_with_encoding(crate:: uncompress_archive_with_encoding). - uncompress_
data - Async version of
uncompress_data.
Type Aliases
- Async
Entry Filter Callback Fn - A filter callback for the async archive iterator.